@@ -30,6 +30,11 @@
 #include "grOGLInt.h"
 #include "utils/paths.h"
 
+/* C99 compat */
+#include "dbwind/dbwind.h"
+#include "utils/main.h"
+#include "utils/malloc.h"
+
 GLubyte 	**grOGLStipples;
 HashTable	grOGLWindowTable;
 Display 	*grXdpy;
@@ -61,7 +66,7 @@ extern void GrOGLLock(), GrOGLUnlock(), GrOGLIconUpdate();
 extern bool GrOGLInit(), GrOGLCreate();
 extern void grOGLWStdin();
 
-
+
 /*---------------------------------------------------------
  * groglSetWMandC:
  *	This is a local routine that resets the value of the current
@@ -111,13 +116,13 @@ groglSetWMandC (mask, c)
        glEnable(GL_BLEND);
        glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
     }
-    glColor4f(fr, fb, fg, aval); 
+    glColor4f(fr, fb, fg, aval);
 
     oldMask = mask;
     oldColor = c;
 }
 
-
+
 /*---------------------------------------------------------
  * groglSetLineStyle:
  *	This local routine sets the current line style.
@@ -154,7 +159,7 @@ groglSetLineStyle (style)
     }
 }
 
-
+
 /*---------------------------------------------------------
  * groglSetSPattern:
  *	xSetSPattern associates stipple patterns with
@@ -191,7 +196,7 @@ groglSetSPattern (sttable, numstipples)
     }
 }
 
-
+
 /*---------------------------------------------------------
  * groglSetStipple:
  *	This routine sets the Xs current stipple number.
@@ -221,7 +226,7 @@ groglSetStipple (stipple)
     }
 }
 
-
+
 /*---------------------------------------------------------
  * GrOGLInit:
  *	GrOGLInit initializes the graphics display and clears its screen.
@@ -247,7 +252,7 @@ GrOGLInit()
 
     grXdpy = XOpenDisplay(NULL);
     if (grXdpy == NULL)
-    {   
+    {
 	TxError("Couldn't open display; check DISPLAY variable\n");
 	return FALSE;
     }
@@ -294,7 +299,7 @@ GrOGLInit()
     if (grVisualInfo != NULL) XFree(grVisualInfo);
     return groglPreLoadFont();
 }
-
+
 /*---------------------------------------------------------
  * GrOGLClose:
  *
@@ -322,7 +327,7 @@ GrOGLClose()
 #endif
 }
 
-
+
 /*---------------------------------------------------------
  * GrOGLFlush:
  * 	Flush output to display.
@@ -391,7 +396,11 @@ oglSetProjection(llx, lly, width, height)
 
     /* scale to fit window */
 
+#ifdef OGL_INVERT_Y
+    glScalef(1.0 / (float)(width >> 1), -1.0 / (float)(height >> 1), 1.0);
+#else
     glScalef(1.0 / (float)(width >> 1), 1.0 / (float)(height >> 1), 1.0);
+#endif
 
     /* magic origin maps to window center; move to window origin */
 
@@ -502,7 +511,7 @@ pipehandler()
 	screenRect.r_xtop = ConfigureEvent->x + width;
 	screenRect.r_ybot = glTransYs(ConfigureEvent->y);
 	screenRect.r_ytop = glTransYs(ConfigureEvent->y + height);
-		 
+
 	SigDisableInterrupts();
 
 	/* Redraw the window */
@@ -558,11 +567,13 @@ pipehandler()
 	if (mw->w_backingStore != (ClientData)NULL)
 	{
 	    Rect surface;
+	    (*GrLockPtr)(mw, FALSE);
 	    (*GrGetBackingStorePtr)(mw, &screenRect);
+	    (*GrUnlockPtr)(mw);
 	    WindScreenToSurface(mw, &screenRect, &surface);
 	    DBWHLRedrawPrepWindow(mw, &surface);
 	    WindDrawBorder(mw, &screenRect);
-	}	
+	}
 	else
 	    WindAreaChanged(mw, &screenRect);
 	WindUpdate(mw);
@@ -570,7 +581,7 @@ pipehandler()
 	} break;
 
       case CreateNotify:	{
-	
+
    	XAnyEvent 	*AnyEvent = (XAnyEvent *) &xevent;
 
 	entry = HashLookOnly(&grOGLWindowTable, AnyEvent->window);
@@ -608,7 +619,7 @@ oglSetDisplay (dispType, outFileName, mouseFileName)
     WindPackageType = WIND_X_WINDOWS;	/* This works okay. */
 
     grCursorType = "bw";
-    
+
     WindScrollBarWidth = 14;
 
     pipe(fildes);
@@ -640,7 +651,7 @@ oglSetDisplay (dispType, outFileName, mouseFileName)
     else {
         fclose(f);
     }
-    
+
     FORK(Xhelper);
     if (Xhelper == 0) {    /* Child process */
         char argv[2][100];
@@ -682,7 +693,7 @@ oglSetDisplay (dispType, outFileName, mouseFileName)
     GrConfigureWindowPtr = GrOGLConfigure;
     GrOverWindowPtr = GrOGLRaise;
     GrUnderWindowPtr = GrOGLLower;
-    GrUpdateIconPtr = GrOGLIconUpdate; 
+    GrUpdateIconPtr = GrOGLIconUpdate;
     GrBitBltPtr = GrOGLBitBlt;
 
     GrFreeBackingStorePtr = groglFreeBackingStore;
@@ -705,9 +716,7 @@ oglSetDisplay (dispType, outFileName, mouseFileName)
     grSetStipplePtr = groglSetStipple;
     grSetLineStylePtr = groglSetLineStyle;
     grSetCharSizePtr = groglSetCharSize;
-#ifdef NONMANHATTAN
     grFillPolygonPtr = groglFillPolygon;
-#endif
 
     if (execFailed) {
         TxError("Execution failed!\n");
@@ -906,7 +915,7 @@ GrOGLDelete(w)
 
     XDestroyWindow(grXdpy, xw);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -954,7 +963,7 @@ GrOGLRaise(w)
 {
     XRaiseWindow(grXdpy, (Window) w->w_grdata );
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -977,7 +986,7 @@ GrOGLLower(w)
 {
     XLowerWindow(grXdpy, (Window) w->w_grdata );
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1010,7 +1019,7 @@ GrOGLLock(w, flag)
 			 w->w_allArea.r_ytop - w->w_allArea.r_ybot);
     }
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -1033,7 +1042,7 @@ GrOGLUnlock(w)
     GrOGLFlush();
     grSimpleUnlock(w);
 }
-
+
 
 /*
  *-------------------------------------------------------------------------
@@ -1055,13 +1064,13 @@ GrOGLIconUpdate(w,text)
      Window wind = (Window) w->w_grdata;
      XClassHint	class;
      char	*brack;
-     
+
      if (w->w_grdata == (ClientData)NULL) return;
      class.res_name = "magic";
      class.res_class = "magic";
      XSetClassHint( grXdpy, wind, &class);
 
-     if (brack = index(text,'['))
+     if (brack = strchr(text,'['))
      {
      	  brack--;
 	  *brack = 0;
@@ -1070,7 +1079,7 @@ GrOGLIconUpdate(w,text)
      	  *brack = ' ';
 	  return;
      }
-     if (brack = rindex(text,' ')) text = brack+1;
+     if (brack = strrchr(text,' ')) text = brack+1;
      XSetIconName(grXdpy,wind,text);
      XStoreName(grXdpy,wind,text);
 }
